experimentalFeatures property

List<Feature> get experimentalFeatures
inherited

Return a list of the experimental features that are to be enabled for tests in this class.

Implementation

List<Feature> get experimentalFeatures => experimentalFeaturesForTests;