testPackageLibPath property
The file system path of the lib directory of the package-under-test.
Implementation
String get testPackageLibPath => '$testPackageRootPath/lib';
The file system path of the lib directory of the package-under-test.
String get testPackageLibPath => '$testPackageRootPath/lib';