testPackageTestPath property

String get testPackageTestPath
inherited

The file system path to the test directory of the package-under-test.

Rarely used except when a test specifically tests files situated inside a package's test directory.

Implementation

String get testPackageTestPath => '$testPackageRootPath/test';