ConfigurationFilesMixin mixin

A mixin adding functionality to write .dart_tool/package_config.json files along with mock packages to a ResourceProvider.

Superclass constraints
Mixin applications

Properties

addFixnumPackageDep bool
Adds the 'fixnum' package as a dependency to the package-under-test.
no setter
addFlutterLocalizationsPackageDep bool
Adds the 'flutter_localizations' package as a dependency to the package-under-test.
no setter
addFlutterPackageDep bool
Adds the 'flutter' package as a dependency to the package-under-test.
no setter
addFlutterTestPackageDep bool
Adds the 'flutter_test' package as a dependency to the package-under-test.
no setter
addMetaPackageDep bool
Adds the 'meta' package as a dependency to the package-under-test.
no setter
addTestReflectiveLoaderPackageDep bool
Adds the 'test_reflective_loader' package as a dependency to the package-under-test.
no setter
addVectorMathPackageDep bool
Adds the 'vector_math' package as a dependency to the package-under-test.
no setter
dartSdkPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
packagesRootPath String
The path to a folder where mock packages can be written.
no setterinherited
pathContext → Context
no setterinherited
resourceProvider → ResourceProvider
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testPackageLanguageVersion String?
The Dart language version of the test package being used for testing.
no setter
testPackageRootPath String
The path to the test package being used for testing.
no setter

Methods

addFfi() → Folder
inherited
addFixnum() → Folder
inherited
addFlutter() → Folder
inherited
addFlutterLocalizations() → Folder
inherited
addMeta() → Folder
inherited
addSkyEngine({required String sdkPath}) → Folder
Adds a mock sky_engine package with an _embedder.yaml file, and returns the Folder of the sky_engine package's 'lib' directory.
inherited
addTestReflectiveLoader() → Folder
inherited
addVectorMath() → Folder
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writePackageConfig2(String projectFolderPath, {String? packageName, PackageConfigFileBuilder? config, String? languageVersion}) → void
Writes a package_config.json for the package at projectFolderPath. If packageName is not supplied, the last segment of projectFolderPath is used.
writeTestPackageConfig2({PackageConfigFileBuilder? config, String? languageVersion}) → void
Writes a package_config.json for the package under test (considered 'package:test') that lives in testPackageRootPath.

Operators

operator ==(Object other) bool
The equality operator.
inherited