testPackageRootPath property
String
get
testPackageRootPath
The path to the test package being used for testing.
Implementation
String get testPackageRootPath;
The path to the test package being used for testing.
String get testPackageRootPath;