experimentalFeaturesForTests top-level property

List<Feature> experimentalFeaturesForTests
final

A list of the experimental features that are to be enabled for tests.

The list will be empty if there are no experiments that should be enabled.

Experiments should be added to this list when work on a new experiment begins. Experiments should be removed from this list when they are marked as being enabled by default.

The features in the list are kept in alphabetic order by experiment flag for ease of determining whether a given feature is already included.

Implementation

final List<Feature> experimentalFeaturesForTests = List.unmodifiable([
  Feature.augmentations,
  Feature.enhanced_parts,
  Feature.static_extensions,
  Feature.this_promotion,
  Feature.variance,
  Feature.receiver_type_inference,
]);