contextFor method
Returns the existing analysis context that should be used to analyze the
given path, or throw StateError if the path is not analyzed in any
of the created analysis contexts.
Implementation
@Deprecated("Use 'contextFor2'")
DriverBasedAnalysisContext contextFor(String path) {
_createAnalysisContexts();
var convertedPath = convertPath(path);
return _analysisContextCollection!.contextFor(convertedPath);
}