contextFor2 method
DriverBasedAnalysisContext
contextFor2(
- File file
inherited
Returns the existing analysis context that should be used to analyze the
given file, or throw StateError if the file is not analyzed in any
of the created analysis contexts.
Implementation
DriverBasedAnalysisContext contextFor2(File file) {
_createAnalysisContexts();
return _analysisContextCollection!.contextFor(file.path);
}