experimentalFeatures property
Return a list of the experimental features that are to be enabled for tests in this class.
Implementation
List<Feature> get experimentalFeatures => experimentalFeaturesForTests;
Return a list of the experimental features that are to be enabled for tests in this class.
List<Feature> get experimentalFeatures => experimentalFeaturesForTests;