experimentalFeatures property
The list of experimental language features to be enabled for these tests.
Implementation
List<Feature> get experimentalFeatures => experimentalFeaturesForTests;
The list of experimental language features to be enabled for these tests.
List<Feature> get experimentalFeatures => experimentalFeaturesForTests;